//				masdll.h
// Header file for the Control Master DLL
///////////////////////////////////////////////

// General Defs
#define MAXBOARDS			30			// maximum number of boards that can be connected to the system

// Board type defs
#define BOARD_MASTER			0		// non isolated master controller
#define BOARD_ISOMASTER			1		// isolated master controller
#define BOARD_DIGITAL_IOSLAVE	2		// digital I/O Slave
#define	BOARD_ANALOGUE_IOSLAVE	3		// analogue I/O slave
#define BOARD_RELAY_SLAVE		4		// relay slave
#define BOARD_MOTOR_SLAVE		5		// motor slave
#define NO_BOARD_DETECTED		123		// no board detected at the specified board number

// error defs
#define SUCCESS						0		// no error
#define ERR_REQUEST_FAILED			-1		// non specific general failure to process command
#define	ERR_INVBOARDNUMBER			-2		// invalid board number specified as parameter
#define ERR_NOMASTERFOUND			-3		// no master controller found
#define ERR_USB_MESSAGING_ERROR		-4		// message received from USB was not as expected (length or header byte)
#define ERR_CHECKSUM				-5		// checksum error in data received from slave
#define ERR_WRONG_BOARD_TYPE		-6		// wrong command for the board type (eg CM_RELAY_Update used with board number of a Motor Slave)

// sub command defs
#define MOTOR_STOP					1		// stop command used within Direction command
#define MOTOR_FORWARD				2		// forward command used within Direction command
#define MOTOR_REVERSE				3		// reverse command used within Direction command


// DLL Function type definitions

typedef int	(*Type_Mas_Initialise)();
typedef int	(*Type_Mas_SendMessage8)(int board, int command, int *message, int *answer);

typedef int	(*Type_CM_Initialise)();
typedef int	(*Type_CM_GetBoardType)(int BoardNumber);

typedef int	(*Type_CM_DIO_Update)(int BoardNumber, int Outputs, int *Inputs);
typedef int	(*Type_CM_DIO_GetStatus)(int BoardNumber, int *Outputs);

typedef int	(*Type_CM_RELAY_Update)(int BoardNumber, int Outputs, int *Inputs);
typedef int	(*Type_CM_RELAY_GetStatus)(int BoardNumber, int *Outputs);

typedef int (*Type_CM_ANIO_Update1to4)(int BoardNumber, int Outputs, int *Inputs, int Sensitivity);
typedef int (*Type_CM_ANIO_Update5to8)(int BoardNumber, int Outputs, int *Inputs, int Sensitivity);
typedef int (*Type_CM_ANIO_GetStatus)(int BoardNumber, int *Outputs, int *Sensitivity);

typedef int (*Type_CM_Motor_M1Speed)(int BoardNumber, int Speed, int *Inputs);
typedef int (*Type_CM_Motor_M1Direction)(int BoardNumber, int Direction, int *Inputs);
typedef int (*Type_CM_Motor_M2Speed)(int BoardNumber, int Speed, int *Inputs);
typedef int (*Type_CM_Motor_M2Direction)(int BoardNumber, int Direction, int *Inputs);
typedef int (*Type_CM_Motor_ReadInputs)(int BoardNumber, int *Inputs);
typedef int (*Type_CM_Motor_GetStatus)(int BoardNumber, int *M1Speed, int *M1Dir, int *M2Speed, int *M2Dir, int *Inputs);

